@@ -4,25 +4,30 @@
 This module provides direct access to the most important functions and classes
 from its submodules.  These are:
 
-- Basic supporting classes and functions: :meth:`base.add_arrows`,
-  :meth:`base.add_hlines`, :meth:`base.add_vlines`, :meth:`base.animate`,
-  :class:`base.ArrowLine`, :meth:`base.closeall`, :meth:`base.figure`,
-  :meth:`base.load_csv`, :meth:`base.save`, :meth:`base.saveall`, :meth:`base.setup_subplots`
+- Basic supporting classes and functions (:mod:`~modelicares.base` module):
+  :meth:`~base.add_arrows`, :meth:`~base.add_hlines`, :meth:`~base.add_vlines`,
+  :meth:`~base.animate`, :class:`~base.ArrowLine`, :meth:`~base.closeall`,
+  :meth:`~base.figure`, :meth:`~base.load_csv`, :meth:`~base.save`,
+  :meth:`~base.saveall`, and :meth:`~base.setup_subplots`
 
-- To manage simulation experiments:  :class:`exps.Experiment`, :mod:`exps.doe`,
-  :meth:`exps.gen_experiments`, :class:`exps.ParamDict`,
-  :meth:`exps.read_params`, :meth:`exps.run_models`, :meth:`exps.write_params`,
-  :meth:`exps.write_script`
+- To manage simulation experiments (:mod:`~modelicares.exps` module):
+  :class:`~exps.Experiment`, :mod:`~exps.doe`, :meth:`~exps.gen_experiments`,
+  :class:`~exps.ParamDict`, :meth:`~exps.read_params`, :meth:`~exps.run_models`,
+  :meth:`~exps.write_params`, and :meth:`~exps.write_script`
 
-- To handle multiple files at once: :meth:`multi.multiload`,
-  :meth:`multi.multiplot`
+- To handle multiple files at once (:mod:`~modelicares.multi` module):
+  :meth:`~multi.multiload`, :meth:`~multi.multiplot`, :meth:`~multi.multibode`,
+  and :meth:`~multi.multinyquist`
 
-- For simulation results: :class:`simres.SimRes`
+- For simulation results (:mod:`~modelicares.simres` module):
+  :class:`~simres.SimRes`
 
-- For linearization results: :class:`linres.LinRes`
+- For linearization results (:mod:`~modelicares.linres` module):
+  :class:`~linres.LinRes`
 
-- To label numbers and quantities: :meth:`texunit.label_number`,
-  :meth:`texunit.label_quantity`, :meth:`texunit.unit2tex`
+- To label numbers and quantities (:mod:`~modelicares.texunit` module):
+  :meth:`~texunit.label_number`, :meth:`~texunit.label_quantity`, and
+  :meth:`~texunit.unit2tex`
 
 .. _Modelica: http://www.modelica.org/
 """
@@ -30,7 +35,7 @@ __author__ = "Kevin Davies"
 __email__ = "kdavies4@gmail.com"
 __copyright__ = "Copyright 2012-2013, Georgia Tech Research Corporation"
 __license__ = "BSD-compatible (see LICENSE.txt)"
-__version__ = "0.8.1"
+__version__ = "0.8.2"
 
 
 import sys
